==> ukui-control-center_3.22.1.25.orig.tar.gz: ukui-control-center-3.22.1.25/plugins/personalized/screenlock/pictureunit.h <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */
#ifndef PICTUREUNIT_H
#define PICTUREUNIT_H

#include <QLabel>
#include <QMouseEvent>
#include <QEvent>
class PictureUnit : public QLabel
{
    Q_OBJECT

public:
    explicit PictureUnit(QWidget *parent = nullptr);
    ~PictureUnit();
 
public:
    void setFilenameText(QString fn);
    void changeClickedFlag(bool flag);
    bool getClickedFlag();
    void enterEvent(QEvent *e);
    void leaveEvent(QEvent *e);
    QString clickedStyleSheet;
    QString filenameText();
protected:
    void mousePressEvent(QMouseEvent * e);
    bool eventFilter(QObject *w, QEvent *e);

private:
    QString _filename;
    bool clickedFlag;
    QString hoverStyleSheet;
    bool isTouchControl;
    QPoint touchBeginPoint;
    QPoint touchEndPoint;

Q_SIGNALS:
    void clicked(QString filename);

};

#endif // PICTUREUNIT_H

==> ukui-control-center_3.22.1.28.orig.tar.gz: ukui-control-center-3.22.1.28/plugins/personalized/screenlock/pictureunit.h <==
/*
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
**/
#ifndef PICTUREUNIT_H
#define PICTUREUNIT_H

#include <QLabel>
#include <QMouseEvent>
#include <QEvent>

class PictureUnit : public QLabel
{
    Q_OBJECT

public:
    explicit PictureUnit(QWidget *parent = nullptr);
    ~PictureUnit();

public:
    void setFilenameText(QString fn);
    QString filenameText();
    void changeClickedFlag(bool flag);
    bool getClickedFlag();
    void enterEvent(QEvent *e);
    void leaveEvent(QEvent *e);
public:
    QString _filename;
    QString clickedStyleSheet;
protected:
    void mouseReleaseEvent(QMouseEvent * e);
    bool eventFilter(QObject *w, QEvent *e);

private:
    bool clickedFlag;
    QString hoverStyleSheet;
    bool isTouchControl;
    QPointF touchBeginPoint;
    QPointF touchEndPoint;

Q_SIGNALS:
    void clicked(QString filename);

};

#endif // PICTUREUNIT_H
